"""
==========
Yo Modules
==========

Python 3 modules for atmospheric research, especially airborne sunphotometry. Yo comes from the Japanese word for the Sun.

.. moduleauthor:: Yohei Shinozuka <Yohei.Shinozuka@nasa.gov>

"""

from .codes4data import *
from .codes4figures import *
from _version import __version__